/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.    
 */
package org.fabric3.introspection.xml;

import javax.xml.namespace.QName;
import javax.xml.stream.XMLStreamReader;

/**
 * Failure that indicates an element was encountered that could not be handled.
 *
 * @version $Rev: 4310 $ $Date: 2008-05-23 11:08:47 -0700 (Fri, 23 May 2008) $
 */
public class UnrecognizedElement extends XmlValidationFailure<QName> {

    /**
     * Constructor that indicates which resource could not be found. The supplied parameter is also returned as the message.
     *
     * @param reader the StAX reader positioned on the unrecognized element
     */
    public UnrecognizedElement(XMLStreamReader reader) {
        super("Unrecognized element", reader.getName(), reader);
    }

    public String getMessage() {
        StringBuffer b = new StringBuffer("The element ").append(getValidatable()).append(" specified in ").append(getResourceURI()).append(
                " at ").append(getLine()).append(",").append(getColumn()).append(" was not recognized. If this is not a typo, check to").append(
                " ensure extensions are configured properly.");
        return b.toString();
    }
}